# https://fedoraproject.org/wiki/Packaging:Haskell

%global pkg_name haskell-platform

%global upstream_version 8.0.2

%global ghc_compiler_version %{upstream_version}
%global alex_version 3.2.1
%global cabal_install_version 1.24.0.2
%global happy_version 1.19.5
%global hscolour_version 1.24.1

%global separate_packages QuickCheck|HTTP|HUnit|StateVar|alex|cabal-install|call-stack|fgl|happy|html|integer-logarithms|mtl|network|parallel|parsec|random|regex-base|regex-compat|regex-posix|stm|syb|text|zlib|async|primitive|split|vector|attoparsec|case-insensitive|hashable|unordered-containers|xhtml|hscolour|tf-random|exceptions|transformers-compat|scientific|network-uri|old-locale|old-time

Name:           haskell-platform
Version:        2017.%{upstream_version}
# Since library subpackages are versioned:
# - release can only be reset if all library versions get bumped simultaneously
#   (eg for a major release)
# - minor release numbers should be incremented monotonically
# - haskell-src version unchanged
Release:        6%{?dist}
Summary:        Standard Haskell distribution

Group:          Development/Tools
License:        BSD
URL:            http://www.haskell.org/platform/
Source0:        http://www.haskell.org/platform/download/%{upstream_version}/%{name}-%{upstream_version}.tar.gz

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros-extra >= 1.6.4

BuildRequires:  alex = %{alex_version}
BuildRequires:  cabal-install = %{cabal_install_version}
BuildRequires:  ghc-compiler = %{ghc_compiler_version}
BuildRequires:  happy = %{happy_version}
BuildRequires:  hscolour = %{hscolour_version}
# GLUT
BuildRequires:  freeglut-devel%{?_isa}
# OpenGL
BuildRequires:  mesa-libGL-devel%{?_isa},mesa-libGLU-devel%{?_isa}
BuildRequires:  ghc-StateVar-devel
# ObjectName:
BuildRequires:  ghc-transformers-devel
# haskell-src:
BuildRequires:  ghc-syb-devel
# OpenGLRaw:
BuildRequires:  ghc-text-devel

# pull in all of ghc for least surprise
# even though strictly libghc is not formally part of HP
Requires:       ghc = %{ghc_compiler_version}
Requires:       alex = %{alex_version}
Requires:       cabal-install >= %{cabal_install_version}
Requires:       happy = %{happy_version}
Requires:       hscolour = %{hscolour_version}
# F17:
Obsoletes:      ghc-haskell-platform < %{version}-%{release}
# F26:
Obsoletes:      ghc-haskell-platform-devel < %{version}-%{release}

%description
Haskell Platform is a suite of stable and well used Haskell libraries
and tools.  It provides a good starting environment for Haskell development.


%global BSDHaskellReport BSD%{space}and%{space}HaskellReport

%global haskell_platform_version %{version}

%if %{defined ghclibdir}
#%%ghc_lib_subpackage fgl-5.5.3.0
%ghc_lib_subpackage fixed-0.2.1.1
#%%ifnarch armv7hl
# OpenGLRaw-2.6.0.0 started failing:
%ghc_lib_subpackage -c mesa-libGLU-devel%{?_isa} GLURaw-2.0.0.3
%ghc_lib_subpackage -c freeglut-devel%{?_isa} GLUT-2.7.0.10
%ghc_lib_subpackage OpenGL-3.0.1.0
%ghc_lib_subpackage -c mesa-libGL-devel%{?_isa} OpenGLRaw-3.2.4.0
#%%endif
%ghc_lib_subpackage half-0.2.2.3
%ghc_lib_subpackage haskell-src-1.0.2.0
%ghc_lib_subpackage ObjectName-1.1.0.1
#%%ghc_lib_subpackage StateVar-1.1.0.4
%endif

%global version %{haskell_platform_version}


%prep
%setup -q -n %{name}-%{upstream_version}

mv packages/* .


%build
%ghc_libs_build $(grep \-E \-v "^(%{?separate_packages})-[0-9]" etc/build.packages)


%install
%ghc_libs_install $(grep \-E \-v "^(%{?separate_packages})-[0-9]" etc/build.packages)
%ghc_strip_dynlinked


%files
%license LICENSE
%doc README


%changelog
* Mon Mar 13 2017 Jens Petersen <petersen@redhat.com> - 2017.8.0.2-6
- enable prof libraries

* Fri Mar 10 2017 Jens Petersen <petersen@redhat.com> - 2017.8.0.2-5
- update to 8.0.2
- 'cgi' and 'multipart' dropped, add 'fixed'
- core haskell-platform now just provides tools
- drop ghc-haskell-platform-devel subpackage

* Fri Feb 10 2017 Jens Petersen <petersen@redhat.com> - 2016.7.10.3-4
- subpackage build like for other packages

* Wed Sep 28 2016 Jens Petersen <petersen@redhat.com> - 2016.7.10.3-3
- rebuild

* Fri Jul 29 2016 Jens Petersen <petersen@redhat.com> - 2016.7.10.3-2
- split-0.2.3.1
- use new ghc_libs_build and ghc_libs_install macros
- disable GL packages for armv7hl (#1372527)

* Thu Jun 23 2016 Jens Petersen <petersen@redhat.com> - 2016.7.10.3-1
- update to new haskell-platform version 7.10.3
- new half multipart ObjectName StateVar subpackages
- haskell98 dropped and cgi is back
- old-locale and old-time packages added
- bump version to 2016 for version bumps and to avoid epoch
- alex-3.1.7, async-2.1.0, attoparsec-0.13.0.2, cabal-install-1.22.9.0,
  HUnit-1.3.1.1, network-uri 2.6.1.0, parallel-3.2.1.0, parsec-3.1.11,
  QuickCheck-2.8.2, scientific-0.3.4.7, split-0.2.3, text-1.2.2.1, zlib-0.6.1.1

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2014.2.0.0.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2014.2.0.0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed May 13 2015 Jens Petersen <petersen@redhat.com> - 2014.2.0.0.3-4
- bump cabal-install to 1.18.1.0 and allow newer versions

* Fri Apr 10 2015 Jens Petersen <petersen@redhat.com> - 2014.2.0.0.2-3
- workaround build-tools version detection failures on aarch64 (#1210323)

* Fri Apr  3 2015 Jens Petersen <petersen@redhat.com> - 2014.2.0.0.2-2
- bump alex to 3.1.4
- bump cabal-install to 1.18.0.8
- bump happy to 1.19.5
- bump QuickCheck to 2.7.6

* Fri Feb  6 2015 Jens Petersen <petersen@redhat.com> - 2014.2.0.0.1-1
- use ghc-7.8.4
- bump attoparsec to 0.11.3.4
- bump text to 1.1.1.3

* Wed Aug 20 2014 Jens Petersen <petersen@redhat.com> - 2014.2.0.0-1
- update to haskell-platform-2014.2
- ghc-7.8.3+ ships xhtml
- cgi dropped
- requires hscolour

* Tue Jul  8 2014 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-37
- rebuild for F21

* Mon Apr 21 2014 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-36
- fix build for versioned docdirs

* Mon Apr 21 2014 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-35
- alex and syb are separate packages again

* Mon Apr 14 2014 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-34
- cabal-install, happy, parallel, regex-compat are now separate packages

* Thu Mar 27 2014 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-33
- transformers lib is now separate package

* Wed Mar 26 2014 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-32
- QuickCheck and HTTP are separate packages again

* Mon Mar 17 2014 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-31
- HUnit is a separate package again
- network is a separate package again

* Thu Feb  6 2014 Jens Petersen <petersen@redhat.com>
- only show cabal-install upgrade notice for verbose

* Mon Feb  3 2014 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-30
- parsec is now a separate package again
- async is now a new separate package

* Wed Jan  8 2014 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-29
- regex-posix is now a separate package

* Fri Jan  3 2014 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-28
- html and regex-base are now separate packages

* Wed Dec  4 2013 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-27
- mtl and zlib are now separate packages again

* Thu Oct 31 2013 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-26
- fix alex patching for ppc and s390 archs

* Sat Oct 26 2013 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-25
- random and stm are separate packages again

* Fri Jul 26 2013 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-24
- fix packaging of license files when building without shared libraries
- tweaks for F20 unversioned docdir

* Sat May  4 2013 Jens Petersen <petersen@redhat.com> - 2013.2.0.0-23
- update to 2013.2.0.0
- new packages: GLURaw, OpenGLRaw
- new depends: attoparsec, case-insensitive, hashable, unordered-containers
- use ghc_fix_dynamic_rpath
- text lib is separate package again

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2012.4.0.0-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Dec  6 2012 Jens Petersen <petersen@redhat.com> - 2012.4.0.0-21
- vector was patched to build on all archs (#883479)

* Wed Dec  5 2012 Jens Petersen <petersen@redhat.com> - 2012.4.0.0-20
- keep split, vector, and primitive in their own existing src packages
- allow building on ghc archs without ghci: ie without vector library (#883479)

* Sat Oct 20 2012 Jens Petersen <petersen@redhat.com> - 2012.4.0.0-19
- update to 2012.4.0.0
- new subpackages: async, split, vector, and primitive (vector dep)
- drop explicit BR hscolour

* Mon Jul 23 2012 Jens Petersen <petersen@redhat.com> - 2012.2.0.0-18
- also apply the alex fix-bang-pattern patch for s390 and s390x

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2012.2.0.0-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jul 16 2012 Jens Petersen <petersen@redhat.com> - 2012.2.0.0-16
- change prof BRs to devel

* Thu Jun  7 2012 Jens Petersen <petersen@redhat.com> - 2012.2.0.0-15
- update to 2012.2.0.0
- build the whole of haskell-platform now from this package
  and subpackage like ghc's libraries
- add alex fix-bang-pattern.diff patch from Debian to fix build on ppc archs
  - requires BR alex
- drop common_summary and common_description for subpackaging
- no longer need to unset debug_package
- make sure all the dynamically linked files get stripped
- needs ghc-rpm-macros 0.95.2 or later to build
- use chrpath to fix the program RPATHs when dynamically linked to HP libs

* Wed May  9 2012 Jens Petersen <petersen@redhat.com> - 2011.4.0.741-2
- update cabal-install to 0.14.0

* Sat Mar 24 2012 Jens Petersen <petersen@redhat.com> - 2011.4.0.741-1
- update to ghc-7.4.1 and latest libraries
- temporarily just a meta-package

* Wed Mar 21 2012 Jens Petersen <petersen@redhat.com> - 2011.4.0.0-7
- require ghc-compiler instead of ghc to avoid the ghc lib

* Fri Jan 20 2012 Jens Petersen <petersen@redhat.com> - 2011.4.0.0-6
- update to cabal2spec-0.25.2

* Thu Jan 19 2012 Jens Petersen <petersen@redhat.com> - 2011.4.0.0-5
- update the description

* Thu Jan 19 2012 Jens Petersen <petersen@redhat.com> - 2011.4.0.0-4
- update the source url

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2011.4.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Jan  1 2012 Jens Petersen <petersen@redhat.com> - 2011.4.0.0-2
- define ghc_without_shared since ghc-haskell-platform-devel no longer
  requires ghc-haskell-platform

* Wed Dec 28 2011 Jens Petersen <petersen@redhat.com> - 2011.4.0.0-1
- update to 2011.4.0.0
- reenable ppc64
- drop ghc-haskell-platform subpackage
- require ghc-libraries instead of ghc-devel

* Tue Jun 21 2011 Jens Petersen <petersen@redhat.com> - 2011.2.0.1-2
- ghc_arches replaces ghc_excluded_archs (cabal2spec-0.23.2)

* Mon Jun 20 2011 Jens Petersen <petersen@redhat.com> - 2011.2.0.1-1
- update to 2011.2.0.1: ghc-7.0.3 and text-0.11.0.6
- update source url
- use ghc_excluded_archs
- exclude ppc64: no QuickCheck
- bump ghc to 7.0.4
- use top_prefix for path to haskell-platform subdir in large tarball
- drop upstream_version

* Fri May 27 2011 Jens Petersen <petersen@redhat.com> - 2011.2.0.0-5
- drop the prof subpackage

* Wed May 25 2011 Jens Petersen <petersen@redhat.com> - 2011.2.0.0-4
- add ppc64 arch

* Mon Mar 28 2011 Jens Petersen <petersen@redhat.com> - 2011.2.0.0-3
- remove duplicate license file from ghc-haskell-platform

* Mon Mar 28 2011 Jens Petersen <petersen@redhat.com> - 2011.2.0.0-2
- fix the install scripts:
- ghc_reindex_haddock is now redundant
- use ghc_pkg_recache

* Fri Mar 11 2011 Jens Petersen <petersen@redhat.com> - 2011.2.0.0-1
- 2011.2.0.0 final

* Thu Mar 10 2011 Fabio M. Di Nitto <fdinitto@redhat.com> - 2011.1.0.0-0.6
- Enable build on sparcv9

* Tue Feb 15 2011 Jens Petersen <petersen@redhat.com> - 2011.1.0.0-0.5
- update to latest haskell-platform-2011.1 snapshot

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2011.1.0.0-0.4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan 22 2011 Jens Petersen <petersen@redhat.com> - 2011.1.0.0-0.3
- make ghc-haskell-platform-devel require ghc-devel and ghc_devel_requires
- build with ghc_lib_build and without_haddock

* Tue Jan 18 2011 Jens Petersen <petersen@redhat.com> - 2011.1.0.0-0.2
- update to cabal2spec-0.22.4

* Sun Dec  5 2010 Jens Petersen <petersen@redhat.com> - 2011.1.0.0-0.1
- update to 2011.1.0.0 alpha snapshot

* Fri Nov 26 2010 Jens Petersen <petersen@redhat.com> - 2010.2.0.0.701-1
- bump some versions for ghc-7.0.1
- add hscolour
- no haddock documentation to build
- remove duplicate LICENSE file

* Fri Jul 23 2010 Jens Petersen <petersen@redhat.com> - 2010.2.0.0-1
- update to 2010.2.0.0 final release (no actual changes)

* Sun Jul 18 2010 Jens Petersen <petersen@redhat.com> - 2010.2.0.0-0.1
- drop debuginfo again: ghc_strip_dynlinked got fixed in ghc-rpm-macros-0.8.1

* Fri Jul 16 2010 Jens Petersen <petersen@redhat.com> - 2010.2.0.0-0.1
- update to 2010.2.0.0 RC
- obsolete ghc-haskell-platform-doc in line with ghc-rpm-macros-0.8.0
- add License to base library too

* Sun Jun 27 2010 Jens Petersen <petersen@redhat.com> - 2010.1.0.0.6123-1
- bump ghc to 6.12.3
- sync cabal2spec-0.22.1
- enable debugging for now to avoid empty strip error

* Thu Apr 29 2010 Jens Petersen <petersen@redhat.com> - 2010.1.0.0.6122-1
- break haskell-platform-2010.1.0.0 with ghc-6.12.2

* Wed Mar 24 2010 Jens Petersen <petersen@redhat.com> - 2010.1.0.0-1
- update to 2010.1.0.0 beta release
- update versions of alex, cgi, network, parallel, QuickCheck, HTTP
- new deepseq dep (#576482)

* Thu Jan 28 2010 Jens Petersen <petersen@redhat.com> - 2009.3.1.20100115-0.2
- add filelist for shared libs
- update devel post and postun

* Sat Jan 16 2010 Jens Petersen <petersen@redhat.com> - 2009.3.1.20100115-0.1
- update to darcs snapshot patched for ghc-6.12.1
- update to ghc-rpm-macros-0.5.1 and cabal2spec-0.21.1:
- drop doc and prof bcond
- use common_summary and common_description
- use ghc_lib_package and ghc_pkg_deps
- build shared library
- drop redundant buildroot and its install cleaning

* Mon Sep 28 2009 Jens Petersen <petersen@redhat.com> - 2009.2.0.2-3
- fix rpmlint warnings (bos, #523883)

* Mon Sep 28 2009 Jens Petersen <petersen@redhat.com> - 2009.2.0.2-2
- add all the buildrequires (#523883)
- create ghcpkgdir since metapackage
- nothing in bindir

* Thu Sep 17 2009 Jens Petersen <petersen@redhat.com> - 2009.2.0.2-1
- initial packaging for Fedora
